summaryrefslogtreecommitdiffstats
path: root/src/OSSupport/File.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/OSSupport/File.h')
-rw-r--r--src/OSSupport/File.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/OSSupport/File.h b/src/OSSupport/File.h
index 6281d1494..b8381ac0e 100644
--- a/src/OSSupport/File.h
+++ b/src/OSSupport/File.h
@@ -80,11 +80,14 @@ public:
bool IsOpen(void) const;
bool IsEOF(void) const;
- /** Reads up to iNumBytes bytes into iBuffer, returns the number of bytes actually read, or -1 on failure; asserts if not open */
- int Read (void * iBuffer, size_t iNumBytes);
+ /** Reads up to a_NumBytes bytes into a_Buffer, returns the number of bytes actually read, or -1 on failure; asserts if not open */
+ int Read(void * a_Buffer, size_t a_NumBytes);
- /** Writes up to iNumBytes bytes from iBuffer, returns the number of bytes actually written, or -1 on failure; asserts if not open */
- int Write(const void * iBuffer, size_t iNumBytes);
+ /** Reads up to a_NumBytes bytes, returns the bytes actually read, or empty string on failure; asserts if not open */
+ AString Read(size_t a_NumBytes);
+
+ /** Writes up to a_NumBytes bytes from a_Buffer, returns the number of bytes actually written, or -1 on failure; asserts if not open */
+ int Write(const void * a_Buffer, size_t a_NumBytes);
/** Seeks to iPosition bytes from file start, returns old position or -1 for failure; asserts if not open */
long Seek (int iPosition);